# Examples

This section illustrates some use cases with **Splitter_MR** to read documents and split them into smaller chunks.

## Text-based splitting

### [RecursiveCharacterSplitter](./recursive_character_splitter.md)

How to divide the text recursively by group of words and sentences.

!!! note
    
    👨‍💻 **Work-in-progress...** More examples to come!